@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997-2013 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2017 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -11,6 +11,12 @@
 */
 #include "SDL.h"
 
+#include <stdio.h> /* for fflush() and stdout */
+
+#ifdef __EMSCRIPTEN__
+#include <emscripten/emscripten.h>
+#endif
+
 static SDL_AudioSpec spec;
 static Uint8 *sound = NULL;     /* Pointer to wave data */
 static Uint32 soundlen = 0;     /* Length of wave data */
@@ -19,9 +25,11 @@ typedef struct
 {
     SDL_AudioDeviceID dev;
     int soundpos;
-    volatile int done;
+    SDL_atomic_t done;
 } callback_data;
 
+callback_data cbd[64];
+
 void SDLCALL
 play_through_once(void *arg, Uint8 * stream, int len)
 {
@@ -38,16 +46,36 @@ play_through_once(void *arg, Uint8 * stream, int len)
     if (len > 0) {
         stream += cpy;
         SDL_memset(stream, spec.silence, len);
-        cbd->done++;
+        SDL_AtomicSet(&cbd->done, 1);
+    }
+}
+
+void
+loop()
+{
+    if (SDL_AtomicGet(&cbd[0].done)) {
+#ifdef __EMSCRIPTEN__
+        emscripten_cancel_main_loop();
+#endif
+        SDL_PauseAudioDevice(cbd[0].dev, 1);
+        SDL_CloseAudioDevice(cbd[0].dev);
+        SDL_FreeWAV(sound);
+        SDL_Quit();
     }
 }
 
 static void
 test_multi_audio(int devcount)
 {
-    callback_data cbd[64];
     int keep_going = 1;
     int i;
+    
+#ifdef __ANDROID__  
+    SDL_Event event;
+  
+    /* Create a Window to get fully initialized event processing for testing pause on Android. */
+    SDL_CreateWindow("testmultiaudio", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, 320, 240, 0);
+#endif
 
     if (devcount > 64) {
         SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Too many devices (%d), clamping to 64...\n",
@@ -69,9 +97,18 @@ test_multi_audio(int devcount)
             SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Open device failed: %s\n", SDL_GetError());
         } else {
             SDL_PauseAudioDevice(cbd[0].dev, 0);
-            while (!cbd[0].done)
+#ifdef __EMSCRIPTEN__
+            emscripten_set_main_loop(loop, 0, 1);
+#else
+            while (!SDL_AtomicGet(&cbd[0].done)) {
+                #ifdef __ANDROID__                
+                /* Empty queue, some application events would prevent pause. */
+                while (SDL_PollEvent(&event)){}
+                #endif                
                 SDL_Delay(100);
+            }
             SDL_PauseAudioDevice(cbd[0].dev, 1);
+#endif
             SDL_Log("done.\n");
             SDL_CloseAudioDevice(cbd[0].dev);
         }
@@ -98,13 +135,19 @@ test_multi_audio(int devcount)
     while (keep_going) {
         keep_going = 0;
         for (i = 0; i < devcount; i++) {
-            if ((cbd[i].dev) && (!cbd[i].done)) {
+            if ((cbd[i].dev) && (!SDL_AtomicGet(&cbd[i].done))) {
                 keep_going = 1;
             }
         }
+        #ifdef __ANDROID__        
+        /* Empty queue, some application events would prevent pause. */
+        while (SDL_PollEvent(&event)){}
+        #endif        
+
         SDL_Delay(100);
     }
 
+#ifndef __EMSCRIPTEN__
     for (i = 0; i < devcount; i++) {
         if (cbd[i].dev) {
             SDL_PauseAudioDevice(cbd[i].dev, 1);
@@ -113,6 +156,7 @@ test_multi_audio(int devcount)
     }
 
     SDL_Log("All done!\n");
+#endif
 }
 
 
@@ -121,7 +165,7 @@ main(int argc, char **argv)
 {
     int devcount = 0;
 
-	/* Enable standard application logging */
+    /* Enable standard application logging */
     SDL_LogSetPriority(SDL_LOG_CATEGORY_APPLICATION, SDL_LOG_PRIORITY_INFO);
 
     /* Load the SDL library */
@@ -131,7 +175,7 @@ main(int argc, char **argv)
     }
 
     SDL_Log("Using audio driver: %s\n", SDL_GetCurrentAudioDriver());
-
+    
     devcount = SDL_GetNumAudioDevices(0);
     if (devcount < 1) {
         SDL_LogError(SDL_LOG_CATEGORY_APPLICATION, "Don't see any specific audio devices!\n");
